@@ -2,11 +2,12 @@
 {
     require(utils)
     cat("\n",paste("ChainLadder version", packageDescription("ChainLadder")$Version,
-                   "by Markus Gesmann <markus.gesmann@gmail.com>\n\n"),
+                   "by:\nMarkus Gesmann <markus.gesmann@gmail.com>,\nWayne (Yanwei) Zhang <actuaryzhang@uchicago.edu>\n\n"),
         "Type library(help='ChainLadder') or ?ChainLadder\n",
         "to see overall documentation.\n\n",
-        "Type example(ChainLadder) to get an idea of the functionality of this package.\n\n",
-        "Feel free to send me an email if you would like to keep ",
+        "Type demo(ChainLadder) to get an idea of the functionality of this package.\n\n",
+        "See demo(package='ChainLadder') for a list of more demos.\n\n",
+        "Feel free to send us an email if you would like to keep ",
         "informed of\nnew versions or if you have any feedback, ",
         "ideas, suggestions or ",
         "would\nlike to collaborate.\n\n",
